import React from 'react';
import { withStyles } from '@material-ui/core/styles';
import ChannelList from './ChannelList';
import ClientList from './ClientList';

const styles = () => ({
  centered: {
    textAlign: 'center',
  },
});

const ChannelEntry = props => {
  const { clients, channel, classes } = props;

  // render Channel Title dependent of spacer-type
  let ChannelTitle;
  if (channel.spacer === 'fill' && channel.name === '_')
    ChannelTitle = (
      <div>
        <hr />
      </div>
    );
  else if (channel.spacer === 'centered')
    ChannelTitle = (
      <div className={classes.centered}>
        <span>{channel.name}</span>
      </div>
    );
  else
    ChannelTitle = (
      <div>
        <span>{channel.name}</span>
      </div>
    );

  // render connected clients, if existent
  const joined = [];
  if (channel.totalClients > 0) {
    clients.forEach(client => {
      if (client.channelId === channel.id) joined.push(client);
    });
  }
  const ConnectedClients = joined.length > 0 && <ClientList clients={joined} />;

  // render another ChannelList if channel has subchannels
  const Subchannels = channel.subchannels !== undefined && (
    <ChannelList channels={channel.subchannels} clients={clients} />
  );

  return (
    <>
      {ChannelTitle}
      {ConnectedClients}
      {Subchannels}
    </>
  );
};

export default withStyles(styles)(ChannelEntry);
