import React, { Component } from 'react';
import { withStyles } from '@material-ui/core/styles';
import { Paper } from '@material-ui/core';
import ApiService from '../services/ApiService';
import ChannelList from './ChannelList';
import parseData from '../parseData';

const styles = theme => ({
  root: {
    ...theme.mixins.gutters(),
    paddingTop: theme.spacing.unit * 2,
    paddingBottom: theme.spacing.unit * 2,
    margin: `${theme.spacing.unit}px auto`,
    width: '500px',
  },
});

class Channels extends Component {
  constructor(props) {
    super(props);
    this.state = {
      loaded: false,
      channels: [],
      clients: [],
    };
  }

  componentDidMount() {
    ApiService.fetchAllChannels().then(data => {
      const { channels, clients } = parseData(data);
      this.setState({
        channels,
        clients,
        loaded: true,
      });
    });
  }

  render() {
    const { loaded, channels, clients } = this.state;
    const { classes } = this.props;
    return (
      <Paper className={classes.root}>
        {!loaded ? (
          <div className='loading'>Loading...</div>
        ) : (
          <ChannelList channels={channels} clients={clients} />
        )}
      </Paper>
    );
  }
}

export default withStyles(styles)(Channels);
